# Dataset

The provided [`Dataset`](__init__.py) class inherits from the [`AnnotationsReadMixin`](mixins/reading.py) and the [`PartMixing`](mixins/parts.py).
Consequently, to create a `Dataset` instance an [`Annotation`](../annotations.py) object is required (it is necessary to pass the names of the arguments!):


```python
from cvdatasets import FileListAnnotations
from cvdatasets import Dataset

annot = FileListAnnotations("path/to/annotation_folder")

train_data = annot.new_dataset(dataset_cls=Dataset, subset="train")
test_data = annot.new_dataset(dataset_cls=Dataset, subset="test")
```

## Working with part and bounding box annotations

In order to enable the [`PartMixing`](mixins/parts.py) functionalities pass the appropriate arguments to the initializer:

```python
data = Dataset(
	uuids=uuids, annotations=annot,

	uniform_parts=True,

	crop_to_bb=True,
	crop_uniform=True,

	parts_in_bb=True,

	rnd_select=True,
	ratio=0.35,
	seed=21486214
)
```

Information about all possible [`PartMixing`](mixins/parts.py) functionalities can be found [here](mixins).
